==> cloudengine-0.3.3.zip: cloudengine-0.3.3/setup.py <==
# -*- coding: utf-8 -*-
from distutils.core import setup


setup(
    name='cloudengine',
    version='0.3.3',
    author=u'Swapnil Talekar',
    author_email='swapnil@getcloudengine.net',
    packages= ['cloudengine', 'cloudengine.classes', 'cloudengine.core',
               'cloudengine.files', 'cloudengine.push', 'cloudengine.users'
                ],
    package_data={ 'cloudengine.classes' : ['fixtures/*.json'],
                   'cloudengine.core' : ['fixtures/*.json'],
                   'cloudengine.files' : ['fixtures/*.json'],
                   'cloudengine.push' : ['fixtures/*.json'],
                   'cloudengine.users' : ['fixtures/*.json'],
                   },
      
    include_package_data = True,
    url='http://github.com/cloudengine/CloudEngine',
    license='MIT license, see LICENCE.txt',
    description='An Open source backend for mobile apps',
    install_requires = ['MySQL-python',
                        'anyjson',
                        'argparse',
                        'azure',
                        'boto',
                        'django-filter',
                        'django-storages',
                        'djangorestframework',
                        'gevent',
                        'gevent-websocket',
                        'greenlet',
                        'gunicorn',
                        'mimeparse',
                        'mock',
                        'pymongo',
                        'python-dateutil',
                        'pytz',
                        'six',
                        'wsgiref',
                        ],
      zip_safe=False,
)

==> cloudengine-0.4.0.zip: cloudengine-0.4.0/setup.py <==
# -*- coding: utf-8 -*-
from distutils.core import setup


setup(
    name='cloudengine',
    version='0.4.0',
    author=u'Swapnil Talekar',
    author_email='swapnil@getcloudengine.net',
    packages= ['cloudengine', 'cloudengine.auth','cloudengine.classes', 'cloudengine.core',
               'cloudengine.files', 'cloudengine.push', 'cloudengine.users', 
               'cloudengine.socketio'
                ],
    package_data={ 'cloudengine.classes' : ['fixtures/*.json'],
                   'cloudengine.core' : ['fixtures/*.json'],
                   'cloudengine.files' : ['fixtures/*.json'],
                   'cloudengine.push' : ['fixtures/*.json'],
                   'cloudengine.users' : ['fixtures/*.json'],
                   },
      
    include_package_data = True,
    url='http://github.com/cloudengine/CloudEngine',
    license='MIT license, see LICENCE.txt',
    description='An Open source backend for mobile apps',
    install_requires = ['MySQL-python',
                        'anyjson',
                        'argparse',
                        'azure',
                        'boto',
                        'django-filter',
                        'django-storages',
                        'djangorestframework',
                        'gevent',
                        'gevent-websocket',
                        'greenlet',
                        'gunicorn',
                        'mimeparse',
                        'mock',
                        'pymongo',
                        'python-dateutil',
                        'pytz',
                        'six',
                        'wsgiref',
                        'django-registration'
                        ],
      zip_safe=False,
)
